<template>
  <el-dialog title="行政处罚没收财物处理审批表"
             :close-on-click-modal="false"
             :visible.sync="visible">
    <!--行政处罚没收财物处理审批表-->
    <el-form :model="dataForm" :rules="dataRules" ref="dataForm" label-width="140px"
             :disabled="dataForm.registerState == '1'">
      <el-row>
        <el-col :span="12">
          <el-form-item label="申请事项">
            <el-input v-model="dataForm.applyItem"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="文书编号" prop="docNumber">
            <el-input v-model="dataForm.docNumber"></el-input>
          </el-form-item>
        </el-col>
      </el-row>

      <el-form-item label="案由" prop="casePoint">
        <el-input v-model="dataForm.casePoint"></el-input>
      </el-form-item>
      <el-row>
        <el-col :span="12">
          <el-form-item label="立案日期" prop="caseDate">
            <el-date-picker
                v-model="dataForm.caseDate"
                :value-format="`yyyy-MM-dd`"
                type="date"
                placeholder="选择日期"
                style="width: 100%">
            </el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="当事人姓名" prop="litigant">
            <el-input v-model="dataForm.litigant"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="法定代表人" prop="legalPerson">
            <el-input v-model="dataForm.legalPerson"></el-input>
          </el-form-item>
        </el-col>
      </el-row>

      <el-row>
        <el-col :span="12">
          <el-form-item label="当事人证件名称" prop="certNo">
            <el-select v-model="dataForm.litigantCert" placeholder="请选择证件类型"
                       :disabled="dataForm.registerState == '1'" style="width: 100%;">
              <el-option
                  v-for="item in cardList"
                  :label="item.label"
                  :value="item.value">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="当事人证件号码" prop="certNo">
            <el-input v-model="dataForm.certNo"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="住址" prop="address">
            <el-input v-model="dataForm.address"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="电话" prop="phone">
            <el-input v-model="dataForm.phone"></el-input>
          </el-form-item>
        </el-col>
      </el-row>

      <el-form-item label="违法事实和处罚内容" prop="casePunish">
        <el-input type="textarea" :row="2" v-model="dataForm.casePunish"></el-input>
      </el-form-item>
      <el-form-item label="没收物品数量" prop="itemAmount">
        <el-input type="textarea" :row="2" v-model="dataForm.itemAmount"></el-input>
      </el-form-item>
      <el-form-item label="处理方式" prop="dealWidth">
        <el-input type="textarea" :row="2" v-model="dataForm.dealWidth"></el-input>
      </el-form-item>
      <el-form-item label="承办人意见" prop="undertakerView">
        <el-input type="textarea" :row="2" v-model="dataForm.undertakerView" disabled></el-input>
      </el-form-item>
      <el-row>
        <el-col :span="12">
          <el-form-item label="承办人" prop="undertakerOne">
            <el-input v-model="dataForm.undertakerOne" disabled></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="承办日期" prop="undertakeDate">
            <el-date-picker
                v-model="dataForm.undertakeDate"
                type="date"
                style="width: 100%"
                placeholder="选择日期" disabled>
            </el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-form-item label="承办人机构意见" prop="takedeptView">
        <el-input type="textarea" :row="2" v-model="dataForm.takedeptView" disabled></el-input>
      </el-form-item>
      <el-row>
        <el-col :span="12">
          <el-form-item label="承办机构负责人" prop="takedeptPerson">
            <el-input v-model="dataForm.takedeptPerson" disabled></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="承办机构审批日期" prop="takeDate">
            <el-date-picker
                v-model="dataForm.takeDate"
                type="date"
                style="width: 100%"
                placeholder="选择日期" disabled>
            </el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-form-item label="行政机关审批意见" prop="organView">
        <el-input type="textarea" :row="2" v-model="dataForm.organView" disabled></el-input>
      </el-form-item>
      <el-row>
        <el-col :span="12">
          <el-form-item label="行政机关负责人" prop="organPerson">
            <el-input v-model="dataForm.organPerson" disabled></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="行政机关审批日期" prop="organDate">
            <el-date-picker
                v-model="dataForm.organDate"
                type="date"
                style="width: 100%"
                placeholder="选择日期" disabled>
            </el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>

      <WordView ref="wordInfo" :isShowYulan="showView" @cancel="cancelWord"></WordView>
    </el-form>
<!--    <div style="text-align: center;">
      <el-button v-show="dataForm.registerState != '1'" plain @click="dataFormSubmit('0')">保存</el-button>
      <el-button v-show="dataForm.registerState != '1'" type="warning" plain @click="dataFormSubmit('1')">定稿</el-button>
      <el-button type="primary" plain @click="viewVord(dataForm)">预览</el-button>
      <el-button type="success" plain @click="downloadWord(dataForm)">下载</el-button>
    </div>-->
  </el-dialog>
</template>
<script>
import WordView from '@/views/News/word-view/index'
import moment from "moment";
import {remote} from "@/api/admin/dict"
import {getObj, saveObj} from "@/api/News/confiscateProperty"

export default {
  name: "fileCase",
  props: ["isShowYulan", 'id', 'processId'],
  components: {
    WordView
  },
  data() {
    return {
      showView: false,
      visible: false,
      dataForm: {
        applyItem: '',
        docNumber: '',
        casePoint: '',
        caseDate: '',
        litigant: '',
        litigantCert: '',
        certNo: '',
        address: '',
        phone: '',
        legalPerson: '',
        casePunish: '',
        itemAmount: '',
        dealWidth: '',
        undertakerView: '',
        undertakerOne: '',
        undertakeDate: '',
        takedeptView: '',
        takedeptPerson: '',
        takeDate: '',
        organView: '',
        organPerson: '',
        organDate: ''
      },
      dataRules: {},
      submitLoading: false,
      cardList: []
    }
  },
  methods: {
    init(id) {
      //查询字典
      remote('document_type').then(res => {
        this.cardList = res.data.data;
      })
      getObj(id).then((res) => {
        if (res.data.code == 0) {
          this.visible = true;
          // 转换null为""
          let v = res.data.data;
          for (let attr in v) {
            if (v[attr] == null) {
              v[attr] = "";
            }
          }
          let str = JSON.stringify(v);
          let data = JSON.parse(str);
          this.dataForm = data;

        }
      });

    },
    /*reset() {
      this.dataForm = {}
    },*/
    cancel() {
      this.$emit('cancel', false);
    },
    dataFormSubmit(type) {
      this.$refs['dataForm'].validate((valid) => {
        if (valid) {
          let obj = this;
          if ("1" == type) {
            this.$confirm('保存为定稿将不能修改，是否继续？', '提示', {
              confirmButtonText: '是',
              cancelButtonText: '否',
              type: 'warning'
            }).then(function () {
              obj.submitLoading = true;
              obj.dataForm.registerState = type;
              obj.dataForm.registerId = obj.id;
              obj.dataForm.processId = obj.processId;
              saveObj(obj.dataForm).then((res) => {
                obj.submitLoading = false;
                if (res.data.code == 0) {
                  obj.$message.success("操作成功");
                  obj.cancel();
                  obj.$emit('getDataList');
                }
              })
            })
          } else {
            this.submitLoading = true;
            this.dataForm.registerState = type;
            this.dataForm.registerId = this.id;
            this.dataForm.processId = this.processId;
            saveObj(this.dataForm).then((res) => {
              this.submitLoading = false;
              if (res.data.code == 0) {
                this.$message.success("操作成功");
                this.cancel();
                this.$emit('getDataList');
              }
            })
          }
        }
      })
    },
    cancelWord() {
      this.showView = false;
    },
    viewVord(data) {
      //↓↓↓↓↓↓以下部分根据具体业务修改↓↓↓↓↓↓
      //格式转换
      let wordData = this.transforData(data);
      //↑↑↑↑↑↑以上部分根据具体业务修改↑↑↑↑↑↑
      this.showView = true;
      this.$nextTick(() => {
        this.$refs.wordInfo.init(wordData, "/lasp.docx");
      })
    },
    downloadWord(data) {
      let wordData = this.transforData(data);
      WordView.methods.exportDoc(wordData, "/lasp.docx", "立案审批表.docx");
    },
    transforData(obj) {
      let s = JSON.stringify(obj);
      let data = JSON.parse(s);
      if (data.caseDate != '' && data.caseDate != null) {
        data.caseDate = moment(data.caseDate).format('YYYY年MM月DD日');
      }
      let opinion = data.publicOpinion;
      for (let attr in opinion) {
        if (opinion[attr] == null) {
          data[attr] = '';
        } else {
          data[attr] = opinion[attr];
        }
      }
      let str = JSON.stringify(data);
      let jsonData = JSON.parse(str);
      data = jsonData;

      if (opinion.undertakeDate != '' && opinion.undertakeDate != null) {
        data.undertakeDate = moment(opinion.undertakeDate).format('YYYY年MM月DD日');
      } else {
        data.undertakeDate = '  年  月  日'
      }
      if (opinion.takeDate != '' && opinion.takeDate != null) {
        data.takeDate = moment(opinion.takeDate).format('YYYY年MM月DD日');
      } else {
        data.takeDate = '  年  月  日'
      }
      if (opinion.legalDate != '' && opinion.legalDate != null) {
        data.legalDate = moment(opinion.legalDate).format('YYYY年MM月DD日');
      } else {
        data.legalDate = '  年  月  日'
      }
      if (opinion.organDate != '' && opinion.organDate != null) {
        data.organDate = moment(opinion.organDate).format('YYYY年MM月DD日');
      } else {
        data.organDate = '  年  月  日'
      }
      return data;
    },
  },

}
</script>

<style scoped>

</style>
